package com.ibiz.core.ht.service.impl;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.HashMap;
import java.math.BigInteger;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.stereotype.Service;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.transaction.annotation.Transactional;
import com.ibiz.core.ht.domain.BC;
import com.ibiz.core.ht.filter.BCSearchContext;
import com.ibiz.core.ht.service.IBCService;
import org.springframework.beans.factory.annotation.Autowired;
import com.ibiz.util.SearchResult;

/**
 * 实体[业务协作] 服务对象接口实现
 */
@Service
public class BCServiceImpl implements IBCService {

    @Autowired
    com.ibiz.core.repository.BCRepository bCRepository;

    @Override
    @Transactional
    public BC get(String bcid) {
        com.ibiz.core.repository.po.BC _t_BC = bCRepository.get(bcid);
        if(_t_BC == null)
            return null ;

        BC _bC = bCRepository.convert2Domain(_t_BC,null) ;

        return _bC;
    }

    @Override
    @Transactional
    public BC get(BC bc) {
        com.ibiz.core.repository.po.BC t_BC = bCRepository.get(bc.getBCId());
        bCRepository.convert2Domain(t_BC,bc);
        return bc;
    }

    @Override
    public BC getDraft(BC bc) {
        return bc;
    }

    @Override
    @Transactional
    public boolean create(BC bc) {
        boolean bOk = false ;
        com.ibiz.core.repository.po.BC t_BC = bCRepository.convert2PO(bc,null);
        bOk = bCRepository.create(t_BC);
        bCRepository.convert2Domain(t_BC,bc);


        return bOk ;
    }

    @Override
    @Transactional
    public boolean remove(String bcid) {
        boolean bOk = false ;

        BC _bC = this.get(bcid);
        bOk = bCRepository.remove(bcid);

        return bOk ;
    }

    @Override
    @Transactional
    public boolean update(BC bc) {
        boolean bOk = false ;
        com.ibiz.core.repository.po.BC t_BC = bCRepository.convert2PO(bc,null);
        bOk = bCRepository.update(t_BC);
        bCRepository.convert2Domain(t_BC,bc) ;
        return bOk ;
    }

    @Override
    public boolean checkKey(BC bc) {
        return true;
    }

    @Override
    @Transactional
    public boolean save(BC bc) {
        if(bc.getBCId()==null){
    		return create(bc);
    	}else{
            if(this.get(bc.getBCId())!=null){
    			return update(bc);
    		}
    		return create(bc);
    	}
    }

    /**
     * 查询集合 DEFAULT
     */
    @Override
    public Page<BC> searchDefault(BCSearchContext context) {
        List<BC> list = new ArrayList<BC>();
        Page<com.ibiz.core.repository.po.BC> t_BCs = bCRepository.searchDefault(context) ;
        for(com.ibiz.core.repository.po.BC t_BC : t_BCs){
            list.add(bCRepository.convert2Domain(t_BC,null));
        }
        return new PageImpl<BC>(list, context.getPageable(), t_BCs.getTotalElements());
    }


    /**
     * 根据重要事项查询
     */
    @Override
    public Page<BC> selectByIM(String imid){
        BCSearchContext context = new BCSearchContext();
        if(!org.springframework.util.StringUtils.isEmpty(imid)){
            com.ibiz.util.SearchFieldFilter fieldFilter=new com.ibiz.util.SearchFieldFilter();
            fieldFilter.setParam("imid");
            fieldFilter.setCondition(com.ibiz.util.enums.SearchFieldType.EQ);
            fieldFilter.setValue(imid);
            context.getCondition().add(fieldFilter);
        }
        List<BC> list = new ArrayList<BC>();
        Page<com.ibiz.core.repository.po.BC> t_BCs = bCRepository.searchDefault(context) ;
        for(com.ibiz.core.repository.po.BC t_BC : t_BCs){
            list.add(bCRepository.convert2Domain(t_BC,null));
        }
        return new PageImpl<BC>(list, context.getPageable(), t_BCs.getTotalElements());
    }

    /**
     * 根据重要事项查询
     */
    @Override
    public List<BC> selectByIM2(String imid){
        BCSearchContext context = new BCSearchContext();
        if(!org.springframework.util.StringUtils.isEmpty(imid)){
            com.ibiz.util.SearchFieldFilter fieldFilter=new com.ibiz.util.SearchFieldFilter();
            fieldFilter.setParam("imid");
            fieldFilter.setCondition(com.ibiz.util.enums.SearchFieldType.EQ);
            fieldFilter.setValue(imid);
            context.getCondition().add(fieldFilter);
        }
        List<BC> list = new ArrayList<BC>();
        Page<com.ibiz.core.repository.po.BC> t_BCs = bCRepository.searchDefault(context) ;
        for(com.ibiz.core.repository.po.BC t_BC : t_BCs){
            list.add(bCRepository.convert2Domain(t_BC,null));
        }
        return list;
    }
    /**
     * 根据部门查询
     */
    @Override
    public Page<BC> selectByORGDEPT(String orgdeptid){
        BCSearchContext context = new BCSearchContext();
        if(!org.springframework.util.StringUtils.isEmpty(orgdeptid)){
            com.ibiz.util.SearchFieldFilter fieldFilter=new com.ibiz.util.SearchFieldFilter();
            fieldFilter.setParam("orgdeptid");
            fieldFilter.setCondition(com.ibiz.util.enums.SearchFieldType.EQ);
            fieldFilter.setValue(orgdeptid);
            context.getCondition().add(fieldFilter);
        }
        List<BC> list = new ArrayList<BC>();
        Page<com.ibiz.core.repository.po.BC> t_BCs = bCRepository.searchDefault(context) ;
        for(com.ibiz.core.repository.po.BC t_BC : t_BCs){
            list.add(bCRepository.convert2Domain(t_BC,null));
        }
        return new PageImpl<BC>(list, context.getPageable(), t_BCs.getTotalElements());
    }

    /**
     * 根据部门查询
     */
    @Override
    public List<BC> selectByORGDEPT2(String orgdeptid){
        BCSearchContext context = new BCSearchContext();
        if(!org.springframework.util.StringUtils.isEmpty(orgdeptid)){
            com.ibiz.util.SearchFieldFilter fieldFilter=new com.ibiz.util.SearchFieldFilter();
            fieldFilter.setParam("orgdeptid");
            fieldFilter.setCondition(com.ibiz.util.enums.SearchFieldType.EQ);
            fieldFilter.setValue(orgdeptid);
            context.getCondition().add(fieldFilter);
        }
        List<BC> list = new ArrayList<BC>();
        Page<com.ibiz.core.repository.po.BC> t_BCs = bCRepository.searchDefault(context) ;
        for(com.ibiz.core.repository.po.BC t_BC : t_BCs){
            list.add(bCRepository.convert2Domain(t_BC,null));
        }
        return list;
    }




}
