package com.ibiz.core.ht.service.impl;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.HashMap;
import java.math.BigInteger;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.stereotype.Service;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.transaction.annotation.Transactional;
import com.ibiz.core.ht.domain.IM;
import com.ibiz.core.ht.filter.IMSearchContext;
import com.ibiz.core.ht.service.IIMService;
import com.ibiz.core.ht.service.logic.IIMGetMPLogic;
import org.springframework.beans.factory.annotation.Autowired;
import com.ibiz.util.SearchResult;

/**
 * 实体[重要事项] 服务对象接口实现
 */
@Service
public class IMServiceImpl implements IIMService {

    @Autowired
    com.ibiz.core.repository.IMRepository iMRepository;

    @Autowired
    private IIMGetMPLogic getmpLogic ;

    @Override
    @Transactional
    public boolean update(IM im) {
        getmpLogic.execute(im);
        boolean bOk = false ;
        com.ibiz.core.repository.po.IM t_IM = iMRepository.convert2PO(im,null);
        bOk = iMRepository.update(t_IM);
        iMRepository.convert2Domain(t_IM,im) ;
        return bOk ;
    }

    @Override
    @Transactional
    public IM hD(IM im) {
        
        return im;
    }

    @Override
    public IM getDraft(IM im) {
        return im;
    }

    @Override
    @Transactional
    public boolean create(IM im) {
        getmpLogic.execute(im);
        boolean bOk = false ;
        com.ibiz.core.repository.po.IM t_IM = iMRepository.convert2PO(im,null);
        bOk = iMRepository.create(t_IM);
        iMRepository.convert2Domain(t_IM,im);


        return bOk ;
    }

    @Override
    @Transactional
    public boolean remove(String imid) {
        boolean bOk = false ;

        IM _iM = this.get(imid);
        bOk = iMRepository.remove(imid);

        return bOk ;
    }

    @Override
    @Transactional
    public boolean save(IM im) {
        if(im.getIMId()==null){
    		return create(im);
    	}else{
            if(this.get(im.getIMId())!=null){
    			return update(im);
    		}
    		return create(im);
    	}
    }

    @Override
    @Transactional
    public IM get(String imid) {
        com.ibiz.core.repository.po.IM _t_IM = iMRepository.get(imid);
        if(_t_IM == null)
            return null ;

        IM _iM = iMRepository.convert2Domain(_t_IM,null) ;

        return _iM;
    }

    @Override
    @Transactional
    public IM get(IM im) {
        com.ibiz.core.repository.po.IM t_IM = iMRepository.get(im.getIMId());
        iMRepository.convert2Domain(t_IM,im);
        return im;
    }

    @Override
    public boolean checkKey(IM im) {
        return true;
    }

    @Override
    @Transactional
    public IM getMP(IM im) {
        
        return im;
    }

    @Override
    @Transactional
    public IM createAndStart(IM im) {
        
        return im;
    }

    /**
     * 查询集合 DEFAULT
     */
    @Override
    public Page<IM> searchDefault(IMSearchContext context) {
        List<IM> list = new ArrayList<IM>();
        Page<com.ibiz.core.repository.po.IM> t_IMs = iMRepository.searchDefault(context) ;
        for(com.ibiz.core.repository.po.IM t_IM : t_IMs){
            list.add(iMRepository.convert2Domain(t_IM,null));
        }
        return new PageImpl<IM>(list, context.getPageable(), t_IMs.getTotalElements());
    }


    /**
     * 根据部门查询
     */
    @Override
    public Page<IM> selectByNGRBM(String orgdeptid){
        IMSearchContext context = new IMSearchContext();
        if(!org.springframework.util.StringUtils.isEmpty(orgdeptid)){
            com.ibiz.util.SearchFieldFilter fieldFilter=new com.ibiz.util.SearchFieldFilter();
            fieldFilter.setParam("orgdeptid");
            fieldFilter.setCondition(com.ibiz.util.enums.SearchFieldType.EQ);
            fieldFilter.setValue(orgdeptid);
            context.getCondition().add(fieldFilter);
        }
        List<IM> list = new ArrayList<IM>();
        Page<com.ibiz.core.repository.po.IM> t_IMs = iMRepository.searchDefault(context) ;
        for(com.ibiz.core.repository.po.IM t_IM : t_IMs){
            list.add(iMRepository.convert2Domain(t_IM,null));
        }
        return new PageImpl<IM>(list, context.getPageable(), t_IMs.getTotalElements());
    }

    /**
     * 根据部门查询
     */
    @Override
    public List<IM> selectByNGRBM2(String orgdeptid){
        IMSearchContext context = new IMSearchContext();
        if(!org.springframework.util.StringUtils.isEmpty(orgdeptid)){
            com.ibiz.util.SearchFieldFilter fieldFilter=new com.ibiz.util.SearchFieldFilter();
            fieldFilter.setParam("orgdeptid");
            fieldFilter.setCondition(com.ibiz.util.enums.SearchFieldType.EQ);
            fieldFilter.setValue(orgdeptid);
            context.getCondition().add(fieldFilter);
        }
        List<IM> list = new ArrayList<IM>();
        Page<com.ibiz.core.repository.po.IM> t_IMs = iMRepository.searchDefault(context) ;
        for(com.ibiz.core.repository.po.IM t_IM : t_IMs){
            list.add(iMRepository.convert2Domain(t_IM,null));
        }
        return list;
    }
    /**
     * 根据组织用户查询
     */
    @Override
    public Page<IM> selectByNGR(String orguserid){
        IMSearchContext context = new IMSearchContext();
        if(!org.springframework.util.StringUtils.isEmpty(orguserid)){
            com.ibiz.util.SearchFieldFilter fieldFilter=new com.ibiz.util.SearchFieldFilter();
            fieldFilter.setParam("orguserid");
            fieldFilter.setCondition(com.ibiz.util.enums.SearchFieldType.EQ);
            fieldFilter.setValue(orguserid);
            context.getCondition().add(fieldFilter);
        }
        List<IM> list = new ArrayList<IM>();
        Page<com.ibiz.core.repository.po.IM> t_IMs = iMRepository.searchDefault(context) ;
        for(com.ibiz.core.repository.po.IM t_IM : t_IMs){
            list.add(iMRepository.convert2Domain(t_IM,null));
        }
        return new PageImpl<IM>(list, context.getPageable(), t_IMs.getTotalElements());
    }

    /**
     * 根据组织用户查询
     */
    @Override
    public List<IM> selectByNGR2(String orguserid){
        IMSearchContext context = new IMSearchContext();
        if(!org.springframework.util.StringUtils.isEmpty(orguserid)){
            com.ibiz.util.SearchFieldFilter fieldFilter=new com.ibiz.util.SearchFieldFilter();
            fieldFilter.setParam("orguserid");
            fieldFilter.setCondition(com.ibiz.util.enums.SearchFieldType.EQ);
            fieldFilter.setValue(orguserid);
            context.getCondition().add(fieldFilter);
        }
        List<IM> list = new ArrayList<IM>();
        Page<com.ibiz.core.repository.po.IM> t_IMs = iMRepository.searchDefault(context) ;
        for(com.ibiz.core.repository.po.IM t_IM : t_IMs){
            list.add(iMRepository.convert2Domain(t_IM,null));
        }
        return list;
    }




}
