package com.ibiz.core.ps.service.impl;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.HashMap;
import java.math.BigInteger;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.stereotype.Service;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import com.ibiz.core.client.model.IPS;
import com.ibiz.core.ps.domain.PS;
import com.ibiz.core.ps.filter.PSSearchContext;
import com.ibiz.core.ps.service.IPSService;
import org.springframework.beans.factory.annotation.Autowired;
import com.ibiz.util.SearchResult;

/**
 * 实体[采购单] 服务对象接口实现
 */
@Service
public class PSServiceImpl implements IPSService {

    @Autowired
    private com.ibiz.core.client.service.IPSClientService pSClientService;

    @Override
    public PS get(String psid) {
        IPS clientModel = pSClientService.createModel();
        clientModel.setPSId(psid);
        pSClientService.get(clientModel) ;
        return this.convert2Domain(clientModel,null);
    }

    @Override
    public PS get(PS ps) {
        PS retps = this.get(ps.getPSId()) ;
    	BeanCopier copier=BeanCopier.create(retps.getClass(), ps.getClass(), false);
        copier.copy(retps, ps, null);
        return ps ;
    }

    @Override
    public boolean update(PS ps) {
        boolean bOk = false ;
        IPS clientModel = this.convert2Model(ps,null);
        pSClientService.update(clientModel) ;
        this.convert2Domain(clientModel,ps) ;
        bOk = true;
        return bOk ;
    }

    @Override
    public boolean create(PS ps) {
        boolean bOk = false ;
        IPS clientModel = this.convert2Model(ps,null);
        pSClientService.create(clientModel) ;
        this.convert2Domain(clientModel,ps);
        bOk = true ;

        return bOk ;
    }

    @Override
    public boolean save(PS ps) {
        if(ps.getPSId()==null){
    		return create(ps);
    	}else{
            if(this.get(ps.getPSId())!=null){
    			return update(ps);
    		}
    		return create(ps);
    	}
    }

    @Override
    public PS getDraft(PS ps) {
        return ps;
    }

    @Override
    public boolean checkKey(PS ps) {
        return true;
    }

    @Override
    public boolean remove(String psid) {
        boolean bOk = false ;
        IPS clientModel = pSClientService.createModel();
        clientModel.setPSId(psid);
        pSClientService.remove(clientModel) ;
        bOk = true ;
        return bOk ;
    }

    /**
     * 查询集合 DEFAULT
     */
    @Override
    public Page<PS> searchDefault(PSSearchContext context) {
        List<PS> list = new ArrayList<PS>();
        Page<com.ibiz.core.client.model.IPS> clientModelList = pSClientService.fetchDefault(context) ;
        for(com.ibiz.core.client.model.IPS clientModel : clientModelList){
            list.add( this.convert2Domain(clientModel,null));
        }
        return new PageImpl<PS>(list, context.getPageable(), clientModelList.getTotalElements());
    }




    public IPS convert2Model(PS domain , IPS model) {
        if(domain == null)
            return model ;
        if(model==null){
            model = pSClientService.createModel() ;
        }

         if(domain.getCreateDateDirtyFlag())
            model.setCreateDate(domain.getCreateDate());
         if(domain.getPSNameDirtyFlag())
            model.setPSName(domain.getPSName());
         if(domain.getCreateManDirtyFlag())
            model.setCreateMan(domain.getCreateMan());
         if(domain.getPSIdDirtyFlag())
            model.setPSId(domain.getPSId());
         if(domain.getUpdateDateDirtyFlag())
            model.setUpdateDate(domain.getUpdateDate());
         if(domain.getUpdateManDirtyFlag())
            model.setUpdateMan(domain.getUpdateMan());
         if(domain.getImstateDirtyFlag())
            model.setImstate(domain.getImstate());
        return model ;
    }

    public PS convert2Domain( IPS model ,PS domain) {
        if(model == null)
            return domain ;
        if(domain == null){
            domain = new PS();
        }

        if(model.getCreateDateDirtyFlag())
            domain.setCreateDate(model.getCreateDate());
        if(model.getPSNameDirtyFlag())
            domain.setPSName(model.getPSName());
        if(model.getCreateManDirtyFlag())
            domain.setCreateMan(model.getCreateMan());
        if(model.getPSIdDirtyFlag())
            domain.setPSId(model.getPSId());
        if(model.getUpdateDateDirtyFlag())
            domain.setUpdateDate(model.getUpdateDate());
        if(model.getUpdateManDirtyFlag())
            domain.setUpdateMan(model.getUpdateMan());
        if(model.getImstateDirtyFlag())
            domain.setImstate(model.getImstate());
        return domain ;
    }


}
